@@ -193,6 +193,36 @@ class 善检网api第2版_套餐_百度(善检网api第2版_套餐):
             print(r)
             return r
 
+    def 获取全部机构id(self, 去除test=True):
+        if 去除test:
+            return list(set(x['机构id'] for x in self.机构概况字典.values() if (('test' not in x['机构名称']) and ('测试' not in x['机构名称']))))
+        return list(set(x['机构id'] for x in self.机构概况字典.values()))
+
+    def 全服新增假日策略(self, 假期名称, 开始日期, 结束日期):
+        rs = {}
+        oids = self.获取全部机构id()
+        total = len(oids)
+        for i, oid in enumerate(oids):
+            print(f"\r{i}\{total}", end='   ')
+            r = self.新增假日策略(机构id=oid, 假期名称=假期名称, 开始日期=开始日期, 结束日期=结束日期)
+            if r[0] is True:
+                rs[oid] = True
+            else:
+                rs[oid] = r[1]
+                print(oid, r[1])
+        return rs
+
+    def 新增假日策略(self, 机构id, 假期名称, 开始日期, 结束日期):
+        data = dict(orgId=机构id, holidayName=假期名称, startTime=开始日期, endTime=结束日期)
+        try:
+            r = self.post("baidu/org/holiday-schedule", data=data)
+            msg = r.get('message') or str(r)
+        except Exception as err:
+            msg = str(err)
+        if msg in ['OK', '成功', 'SUCCESS']:
+            return True, msg
+        return False, msg
+
     def 获取机构排期默认策略(self, 机构id):
         机构id = self.机构概况字典[机构id]['机构id']
         data = self.get('baidu/org/default-schedule', params=dict(orgId=机构id))['data']
@@ -722,12 +752,12 @@ class 善检网api第2版_套餐_百度(善检网api第2版_套餐):
         print(f'修改失败: {fails.keys()}')
         return fails
     
-    def 同步服务(self, 单位, id=None):
+    def 同步服务(self, 单位, id=None, 打印=True):
         类型字典 = dict(服务=1, 品牌=2, 机构=3, 全部=4, 服务基础=5)
         params = {'type': 类型字典[单位]}
         if id: params['id'] = str(id)
         r = self.post("baidu/service/syn/part", data=params)
-        print(r)
+        if 打印: print(r)
         if r['message'] in ('SUCCESS', ):
             return True
         else:
