@@ -172,6 +172,36 @@ class 善检网api第2版_套餐_腾讯(善检网api第2版_套餐):
         params['per'] = self.get("tencent/org-items", params=params)['total']
         return self.get("tencent/org-items", params=params)['data']
 
+    def 获取全部机构id(self, 去除test=True):
+        if 去除test:
+            return list(set(x['机构id'] for x in self.机构字典.values() if (('test' not in x['机构名称']) and ('测试' not in x['机构名称']))))
+        return list(set(x['机构id'] for x in self.机构字典.values()))
+
+    def 全服新增假日策略(self, 假期名称, 开始日期, 结束日期):
+        rs = {}
+        oids = self.获取全部机构id()
+        total = len(oids)
+        for i, oid in enumerate(oids):
+            print(f"\r{i}\{total}", end='   ')
+            r = self.新增假日策略(机构id=oid, 假期名称=假期名称, 开始日期=开始日期, 结束日期=结束日期)
+            if r[0] is True:
+                rs[oid] = True
+            else:
+                rs[oid] = r[1]
+                print(oid, r[1])
+        return rs
+
+    def 新增假日策略(self, 机构id, 假期名称, 开始日期, 结束日期):
+        data = dict(orgId=机构id, holidayName=假期名称, startTime=开始日期, endTime=结束日期)
+        try:
+            r = self.post("tencent/org/holiday-schedule", data=data)
+            msg = r.get('message') or str(r)
+        except Exception as err:
+            msg = str(err)
+        if msg in ['OK', '成功', 'SUCCESS']:
+            return True, msg
+        return False, msg
+
     
     ''' 已测试通过 '''
     def 套餐列表(self, 机构id, 套餐名称=None, 上架=None, 创建时间范围=(None, None)):
